==> cdebootstrap_0.3.15ubuntu1.tar.gz: cdebootstrap-0.3.15ubuntu1/include/install.h <==
/*
 * install.h
 *
 * Copyright (C) 2003 Bastian Blank <waldi@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $LastChangedBy: bastian $
 * $LastChangedDate: 2006-08-24 19:40:20 +0000 (Do, 24 Aug 2006) $
 * $LastChangedRevision: 1243 $
 */

#ifndef INSTALL_H
#define INSTALL_H

#include "packages.h"

int install (di_packages *packages, di_packages_allocator *allocator, di_slist *install);

int install_apt_cleanup (void);
int install_apt_install (di_packages *packages, di_slist *install);
int install_apt_prepare (void);

int install_count_install (di_slist *install);

int install_dev_cleanup (void);
int install_dev_prepare (void);

int install_dpkg_configure (di_packages *packages, int force);
int install_dpkg_install (di_packages *packages, di_slist *install, int force);
int install_dpkg_unpack (di_packages *packages, di_slist *install);

int install_extract (di_slist *install);

di_slist *install_list (di_packages *packages, di_packages_allocator *allocator, di_slist *install, di_package_priority priority, di_package_status status);
di_slist *install_list_package (di_packages *packages, di_packages_allocator *allocator, char *package, di_package_status status);
di_slist *install_list_package_only (di_packages *packages, char *package, di_package_status status);

int install_helper_execute (const char *name);
int install_helper_install (const char *name);
int install_helper_remove (const char *name);

int install_mount_dev (void);
int install_mount_proc (void);
void install_umount (void);

int install_init (const char *helperdir);

int install_target_check (const char *target);

extern char install_root[];
extern const char *helperdir;

#endif

==> cdebootstrap_0.4.4ubuntu1.tar.gz: cdebootstrap-0.4.4ubuntu1/include/install.h <==
/*
 * install.h
 *
 * Copyright (C) 2003 Bastian Blank <waldi@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $LastChangedBy: bastian $
 * $LastChangedDate: 2007-05-13 19:04:33 +0000 (So, 13 Mai 2007) $
 * $LastChangedRevision: 1442 $
 */

#ifndef INSTALL_H
#define INSTALL_H

#include "packages.h"

int install (di_packages *packages, di_packages_allocator *allocator, di_slist *install);

int install_apt_install (di_packages *packages, di_slist *install);

int install_dpkg_configure (di_packages *packages, int force);
int install_dpkg_install (di_packages *packages, di_slist *install, int force);
int install_dpkg_unpack (di_packages *packages, di_slist *install);

int install_extract (di_slist *install);

di_slist *install_list (di_packages *packages, di_packages_allocator *allocator, di_slist *install, di_package_priority priority, di_package_status status);
di_slist *install_list_package (di_packages *packages, di_packages_allocator *allocator, char *package, di_package_status status);
di_slist *install_list_package_only (di_packages *packages, char *package, di_package_status status);

int install_helper_install (const char *name);
int install_helper_remove (const char *name);

int install_mount (const char *what);
void install_umount (void);

int install_init (const char *helperdir);

int install_target_check (const char *target);

extern char install_root[];

#endif
